@@ -42,10 +42,7 @@ class DynamicRegressor():
         # obtain time series forecast -----
 
         input_series = df.drop(columns=['date']).values
-        y = stats.ts(FloatVector([item for sublist in input_series.tolist() for item in sublist]))                
-        print("y")
-        print(y)
-        print("\n")
+        y = stats.ts(FloatVector([item for sublist in input_series.tolist() for item in sublist]))                        
         self.fcast = ahead.dynrmf(y=y, h=self.h, level=self.level, type_pi=self.type_pi)         
 
 
