@@ -76,7 +76,7 @@ class Ridge2Regressor():
 
         # result -----
         
-        if self.date_formatting is "original": 
+        if self.date_formatting == "original": 
         # to be put in utils/ as a function (DRY)
             for j in range(n_series):
                 averages_series_j  = []
@@ -92,7 +92,7 @@ class Ridge2Regressor():
                 ranges.append(ranges_series_j) 
 
 
-        if self.date_formatting is "ms": 
+        if self.date_formatting == "ms": 
             # to be put in utils/ as a function (DRY)
             for j in range(n_series):
                 averages_series_j  = []
